:py:mod:`icclim.generic.registry`
=================================

.. py:module:: icclim.generic.registry

.. autoapi-nested-parse::

   Contain the registry of generic indicators.



Module Contents
---------------

.. py:class:: GenericIndicatorRegistry




   Registry of generic indicators.
